@@ -1,7 +1,7 @@
 /*
  *	Blade DLL Interface for LAME.
  *
- *	Copyright (c) 1999 A.L. Faber
+ *	Copyright (c) 1999 - 2001 A.L. Faber
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,17 +19,28 @@
  * Boston, MA  02111-1307, USA.
  */
 
+#include <windows.h>
+#include <Windef.h>
 #include "BladeMP3EncDLL.h"
 #include <assert.h>
-#include "version.h"  
-#include "VbrTag.h"   
+
+// This DLL should be a wrapper around libmp3lame, and thus only need to 
+// include 'lame.h'.  However, the DLL provides better version information
+// that is currently available via libmp3lame and thus needs version.h
+// (is this still true as of 6/2001?).  Also, DLL has not been updated
+// to use the lame_set/get functions, and so still needs lame_global_flags.h
+// All of this is fine for the DLL (which is recompiled everytime LAME
+// changes, but you are writing your own wrapper to libmp3lame, dont
+// follow this example :-) 
 #include "lame.h"
-#include "util.h"
+#include "lame_global_flags.h"
+#include "version.h"
+
 
 #define _RELEASEDEBUG 0
 
 const int MAJORVERSION=1;
-const int MINORVERSION=16;
+const int MINORVERSION=22;
 
 
 // Local variables
@@ -39,7 +50,7 @@ static BOOL					gs_bLogFile=FALSE;
 static lame_global_flags	gf;
 
 // Local function prototypes
-static void dump_config( char *inPath, char *outPath);
+static void dump_config( );
 static void DebugPrintf(const char* pzFormat, ...);
 static void DispErr(LPSTR strErr);
 static void PresetOptions(lame_global_flags *gfp,LONG myPreset);
@@ -92,7 +103,7 @@ static void DebugPrintf(const char* pzFormat, ...)
 }
 
 
-static void PresetOptions(lame_global_flags *gfp,LONG myPreset)
+static void PresetOptions( lame_global_flags *gfp, LONG myPreset )
 {
 	switch (myPreset)
 	{
@@ -100,10 +111,10 @@ static void PresetOptions(lame_global_flags *gfp,LONG myPreset)
 		case LQP_NORMAL_QUALITY:
 			break;
 		break;
-		case LQP_LOW_QUALITY:		// -f flag
+		case LQP_LOW_QUALITY:
 			gf.quality=9;
 			break;
-		case LQP_HIGH_QUALITY:		// -h flag for high qualtiy
+		case LQP_HIGH_QUALITY:
 			gf.quality=2;
 			break;
 		case LQP_VOICE_QUALITY:		// --voice flag for experimental voice mode
@@ -111,124 +122,124 @@ static void PresetOptions(lame_global_flags *gfp,LONG myPreset)
 			gf.VBR_max_bitrate_kbps=160;
 			gf.no_short_blocks=1;
 		break;
+		case LQP_R3MIX_QUALITY:
+			gf.VBR = vbr_rh; 
+			gf.VBR_q = 1;
+			gf.quality = 2;
+			gf.lowpassfreq = 19500;
+			gf.mode = JOINT_STEREO;
+			gf.ATHtype = 3 ;
+			gf.VBR_min_bitrate_kbps=112;
+		break;
+
 
 		case LQP_PHONE:
 			gfp->out_samplerate =  8000;
-			gfp->lowpassfreq=3200;
-			gfp->lowpasswidth=1000;
-			gfp->no_short_blocks=1;
+			gfp->lowpassfreq = 3200;
+			gfp->lowpasswidth = 1000;
+			gfp->no_short_blocks = 1;
 			gfp->quality = 5;
-			gfp->mode = MPG_MD_MONO; 
-			gfp->mode_fixed = 1; 
+			gfp->mode = MONO; 
 			gfp->brate = 16; 
-			gfp->VBR_q=6;
-			gfp->VBR_min_bitrate_kbps=8;
-			gfp->VBR_max_bitrate_kbps=56;
+			gfp->VBR_q = 6;
+			gfp->VBR_min_bitrate_kbps = 8;
+			gfp->VBR_max_bitrate_kbps = 56;
 		break;
 
 		case LQP_SW:
 			gfp->out_samplerate =  11025;
-			gfp->lowpassfreq=4800;
-			gfp->lowpasswidth=500;
+			gfp->lowpassfreq = 4800;
+			gfp->lowpasswidth = 500;
 			gfp->quality = 5;
-			gfp->mode = MPG_MD_MONO; 
-			gfp->mode_fixed = 1; 
+			gfp->mode = MONO; 
 			gfp->brate = 24; 
-			gfp->VBR_q=5;
-			gfp->VBR_min_bitrate_kbps=8;
-			gfp->VBR_max_bitrate_kbps=64;
+			gfp->VBR_q = 5;
+			gfp->VBR_min_bitrate_kbps = 8;
+			gfp->VBR_max_bitrate_kbps = 64;
 		break;
 		case LQP_AM:
 			gfp->out_samplerate =  16000;
-			gfp->lowpassfreq=7200;
-			gfp->lowpasswidth=500;
+			gfp->lowpassfreq = 7200;
+			gfp->lowpasswidth = 500;
 			gfp->quality = 5;
-			gfp->mode = MPG_MD_MONO; 
-			gfp->mode_fixed = 1; 
+			gfp->mode = MONO; 
 			gfp->brate = 32; 
-			gfp->VBR_q=5;
-			gfp->VBR_min_bitrate_kbps=16;
-			gfp->VBR_max_bitrate_kbps=128;
+			gfp->VBR_q = 5;
+			gfp->VBR_min_bitrate_kbps = 16;
+			gfp->VBR_max_bitrate_kbps = 128;
 		break;
 		case LQP_FM:
-			gfp->out_samplerate =  22050; 
-			gfp->lowpassfreq=9950;
-			gfp->lowpasswidth=880;
+			gfp->out_samplerate = 22050; 
+			gfp->lowpassfreq = 9950;
+			gfp->lowpasswidth = 880;
 			gfp->quality = 5;
-			gfp->mode = MPG_MD_JOINT_STEREO; 
-			gfp->mode_fixed = 1; 
+			gfp->mode = JOINT_STEREO; 
 			gfp->brate = 64; 
-			gfp->VBR_q=5;
-			gfp->VBR_min_bitrate_kbps=24;
-			gfp->VBR_max_bitrate_kbps=160;
+			gfp->VBR_q = 5;
+			gfp->VBR_min_bitrate_kbps = 24;
+			gfp->VBR_max_bitrate_kbps = 160;
 		break;
 		case LQP_VOICE:
-			gfp->out_samplerate =  32000; 
-			gfp->lowpassfreq=12300;
-			gfp->lowpasswidth=2000;
-			gfp->no_short_blocks=1;
+			gfp->out_samplerate = 32000; 
+			gfp->lowpassfreq = 12300;
+			gfp->lowpasswidth = 2000;
+			gfp->no_short_blocks = 1;
 			gfp->quality = 5;
-			gfp->mode = MPG_MD_MONO; 
-			gfp->mode_fixed = 1; 
+			gfp->mode = MONO; 
 			gfp->brate = 56; 
-			gfp->VBR_q=4;
-			gfp->VBR_min_bitrate_kbps=32;
-			gfp->VBR_max_bitrate_kbps=128;
+			gfp->VBR_q = 4;
+			gfp->VBR_min_bitrate_kbps = 32;
+			gfp->VBR_max_bitrate_kbps = 128;
 		break;
 		case LQP_RADIO:
-			gfp->lowpassfreq=15000;
-			gfp->lowpasswidth=0;
+			gfp->lowpassfreq = 15000;
+			gfp->lowpasswidth = 0;
 			gfp->quality = 5;
-			gfp->mode = MPG_MD_JOINT_STEREO; 
-			gfp->mode_fixed = 1; 
+			gfp->mode = JOINT_STEREO; 
 			gfp->brate = 112; 
-			gfp->VBR_q=4;
-			gfp->VBR_min_bitrate_kbps=64;
-			gfp->VBR_max_bitrate_kbps=256;
+			gfp->VBR_q = 4;
+			gfp->VBR_min_bitrate_kbps = 64;
+			gfp->VBR_max_bitrate_kbps = 256;
 		break;
 		case LQP_TAPE:
-			gfp->lowpassfreq=18500;
-			gfp->lowpasswidth=2000;
+			gfp->lowpassfreq = 18500;
+			gfp->lowpasswidth = 2000;
 			gfp->quality = 5;
-			gfp->mode = MPG_MD_JOINT_STEREO; 
-			gfp->mode_fixed = 1; 
+			gfp->mode = JOINT_STEREO; 
 			gfp->brate = 128; 
-			gfp->VBR_q=4;
-			gfp->VBR_min_bitrate_kbps=96;
-			gfp->VBR_max_bitrate_kbps=320;
+			gfp->VBR_q = 4;
+			gfp->VBR_min_bitrate_kbps = 96;
+			gfp->VBR_max_bitrate_kbps = 320;
 		break;
 		case LQP_HIFI:
-			gfp->lowpassfreq=20240;
-			gfp->lowpasswidth=2200;
+			gfp->lowpassfreq = 20240;
+			gfp->lowpasswidth = 2200;
 			gfp->quality = 2;
-			gfp->mode = MPG_MD_JOINT_STEREO; 
-			gfp->mode_fixed = 1; 
+			gfp->mode = JOINT_STEREO; 
 			gfp->brate = 160;            
-			gfp->VBR_q=3;
-			gfp->VBR_min_bitrate_kbps=112;
-			gfp->VBR_max_bitrate_kbps=320;
+			gfp->VBR_q = 3;
+			gfp->VBR_min_bitrate_kbps = 112;
+			gfp->VBR_max_bitrate_kbps = 320;
 		break;
 		case LQP_CD:
-			gfp->lowpassfreq=-1;
-			gfp->highpassfreq=-1;
+			gfp->lowpassfreq = -1;
+			gfp->highpassfreq = -1;
 			gfp->quality = 2;
-			gfp->mode = MPG_MD_STEREO; 
-			gfp->mode_fixed = 1; 
+			gfp->mode = STEREO; 
 			gfp->brate = 192;  
-			gfp->VBR_q=2;
-			gfp->VBR_min_bitrate_kbps=128;
-			gfp->VBR_max_bitrate_kbps=320;
+			gfp->VBR_q = 2;
+			gfp->VBR_min_bitrate_kbps = 128;
+			gfp->VBR_max_bitrate_kbps = 320;
 		break;
 		case LQP_STUDIO:
-			gfp->lowpassfreq=-1;
-			gfp->highpassfreq=-1;
+			gfp->lowpassfreq = -1;
+			gfp->highpassfreq = -1;
 			gfp->quality = 2; 
-			gfp->mode = MPG_MD_STEREO; 
-			gfp->mode_fixed = 1; 
+			gfp->mode = STEREO; 
 			gfp->brate = 256; 
-			gfp->VBR_q=0;
-			gfp->VBR_min_bitrate_kbps=160;
-			gfp->VBR_max_bitrate_kbps=320;
+			gfp->VBR_q = 0;
+			gfp->VBR_min_bitrate_kbps = 160;
+			gfp->VBR_max_bitrate_kbps = 320;
 		break;
 	}
 }
@@ -240,7 +251,7 @@ __declspec(dllexport) BE_ERR	beInitStream(PBE_CONFIG pbeConfig, PDWORD dwSamples
 	BE_CONFIG	lameConfig;
 
 	// Init the global flags structure
-    lame_init(&gf);
+	lame_init_old(&gf);
 
 	// clear out structure
 	memset(&lameConfig,0x00,CURRENT_STRUCT_SIZE);
@@ -271,9 +282,9 @@ __declspec(dllexport) BE_ERR	beInitStream(PBE_CONFIG pbeConfig, PDWORD dwSamples
 		// Get VBR setting from fourth nibble
 		if (nVBR>0)
 		{
-			lameConfig.format.LHV1.bWriteVBRHeader=TRUE;
-			lameConfig.format.LHV1.bEnableVBR=TRUE;
-			lameConfig.format.LHV1.nVBRQuality=nVBR-1;
+			lameConfig.format.LHV1.bWriteVBRHeader = TRUE;
+			lameConfig.format.LHV1.bEnableVBR = TRUE;
+			lameConfig.format.LHV1.nVBRQuality = nVBR-1;
 		}
 
 		// Get Quality from third nibble
@@ -303,23 +314,19 @@ __declspec(dllexport) BE_ERR	beInitStream(PBE_CONFIG pbeConfig, PDWORD dwSamples
 		{
 			case BE_MP3_MODE_STEREO:
 				gf.mode=0;
-				gf.mode_fixed=1;  /* dont allow LAME to change the mode */
 				gf.num_channels=2;
 			break;
 			case BE_MP3_MODE_JSTEREO:
 				gf.mode=1;
-				gf.mode_fixed=1;
 				gf.num_channels=2;
 			break;
 			case BE_MP3_MODE_MONO:
 				gf.mode=3;
-				gf.mode_fixed=1;
 				gf.num_channels=1;
 			break;
 			case BE_MP3_MODE_DUALCHANNEL:
 				gf.force_ms=1;
 				gf.mode=1;
-				gf.mode_fixed=1;
 				gf.num_channels=2;
 			break;
 			default:
@@ -329,11 +336,11 @@ __declspec(dllexport) BE_ERR	beInitStream(PBE_CONFIG pbeConfig, PDWORD dwSamples
 			}
 		}
 
-		if (lameConfig.format.LHV1.bEnableVBR)
+		if ( lameConfig.format.LHV1.bEnableVBR )
 		{
-			// 0=no vbr 1..10 is VBR quality setting -1
-			gf.VBR=vbr_default;
-			gf.VBR_q=lameConfig.format.LHV1.nVBRQuality;
+			gf.VBR = vbr_default;
+
+			gf.VBR_q =lameConfig.format.LHV1.nVBRQuality;
 
 			if (lameConfig.format.LHV1.bWriteVBRHeader==TRUE)
 			{
@@ -344,6 +351,10 @@ __declspec(dllexport) BE_ERR	beInitStream(PBE_CONFIG pbeConfig, PDWORD dwSamples
 				gf.bWriteVbrTag=FALSE;
 			}
 		}
+		else
+		{
+			gf.VBR = vbr_off;
+		}
 
 		// Set frequency resampling rate, if specified
 		if (lameConfig.format.LHV1.dwReSampleRate>0)
@@ -366,11 +377,46 @@ __declspec(dllexport) BE_ERR	beInitStream(PBE_CONFIG pbeConfig, PDWORD dwSamples
 
 			// calculate to kbps
 			gf.VBR_mean_bitrate_kbps = ( lameConfig.format.LHV1.dwVbrAbr_bps + 500 ) / 1000;
+
 			// limit range
-			gf.VBR_mean_bitrate_kbps = Min(gf.VBR_mean_bitrate_kbps,320); 
-			gf.VBR_mean_bitrate_kbps = Max(gf.VBR_mean_bitrate_kbps,8); 
+			if(gf.VBR_mean_bitrate_kbps > 320) gf.VBR_mean_bitrate_kbps = 320;
+			if(gf.VBR_mean_bitrate_kbps <   8) gf.VBR_mean_bitrate_kbps = 8;
+
 		}
 
+
+		if ( lameConfig.format.LHV1.bEnableVBR )
+		{
+			switch ( lameConfig.format.LHV1.nVbrMethod)
+			{
+				case VBR_METHOD_NONE:
+					gf.VBR = vbr_off;
+				break;
+
+				case VBR_METHOD_DEFAULT:
+					gf.VBR = vbr_default;
+				break;
+
+				case VBR_METHOD_OLD:
+					gf.VBR = vbr_rh; 
+				break;
+
+				case VBR_METHOD_NEW:
+					gf.VBR = vbr_mt; 
+				break;
+
+				case VBR_METHOD_MTRH:
+					gf.VBR = vbr_mtrh; 
+				break;
+
+				case VBR_METHOD_ABR:
+					gf.VBR = vbr_abr; 
+				break;
+				default:
+					assert( FALSE );
+
+			}
+		}
 	}
 	
 	// Set copyright flag?
@@ -397,7 +443,7 @@ __declspec(dllexport) BE_ERR	beInitStream(PBE_CONFIG pbeConfig, PDWORD dwSamples
 		gf.error_protection=0;
 	}
 
-	gf.silent=1;  /* disable status ouput */
+//	gf.silent=1;  /* disable status ouput */
 
 	// Set private bit?
 	if (lameConfig.format.LHV1.bPrivate)
@@ -412,7 +458,7 @@ __declspec(dllexport) BE_ERR	beInitStream(PBE_CONFIG pbeConfig, PDWORD dwSamples
 
 	// First set all the preset options
 	if ((int)lameConfig.format.LHV1.nPreset)
-		PresetOptions(&gf,lameConfig.format.LHV1.nPreset);
+		PresetOptions( &gf, lameConfig.format.LHV1.nPreset );
 
 	if (lameConfig.format.LHV1.bNoRes)
 	{
@@ -426,24 +472,22 @@ __declspec(dllexport) BE_ERR	beInitStream(PBE_CONFIG pbeConfig, PDWORD dwSamples
 	if (gf.version==0)
 	{
 		// For MPEG-II, only 576 samples per frame per channel
-		*dwSamples=576*gf.num_channels;
+		*dwSamples= 576 * gf.num_channels;
 	}
 	else
 	{
 		// For MPEG-I, 1152 samples per frame per channel
-		*dwSamples=1152*gf.num_channels;
+		*dwSamples= 1152 * gf.num_channels;
 	}
 
 	// Set the input sample buffer size, so we know what we can expect
-	dwSampleBufferSize=*dwSamples;
-
-	// Set MP3 buffer size
-	// conservative estimate
-	*dwBufferSize=1.25*(*dwSamples/gf.num_channels) + 7200;
+	dwSampleBufferSize = *dwSamples;
 
+	// Set MP3 buffer size, conservative estimate
+	*dwBufferSize=(DWORD)(1.25*(*dwSamples/gf.num_channels) + 7200);
 
 	// For debugging purposes
-	dump_config(gf.inPath,gf.outPath);
+	dump_config( );
 
 	// Everything went OK, thus return SUCCESSFUL
 	return BE_ERR_SUCCESSFUL;
@@ -453,13 +497,22 @@ __declspec(dllexport) BE_ERR	beInitStream(PBE_CONFIG pbeConfig, PDWORD dwSamples
 __declspec(dllexport) BE_ERR	beDeinitStream(HBE_STREAM hbeStream, PBYTE pOutput, PDWORD pdwOutput)
 {
 
-	*pdwOutput = lame_encode_finish(&gf,pOutput,0);
+//	*pdwOutput = lame_encode_finish(&gf,pOutput,0);
+
+    *pdwOutput = lame_encode_flush( &gf, pOutput, 0 );
 
 	if (*pdwOutput<0) {
 		*pdwOutput=0;
 		return BE_ERR_BUFFER_TOO_SMALL;
 	}
 
+    
+
+	if ( !gf.bWriteVbrTag )
+	{
+		lame_close( &gf );
+	}
+
 	return BE_ERR_SUCCESSFUL;
 }
 
@@ -487,6 +540,16 @@ __declspec(dllexport) VOID		beVersion(PBE_VERSION pbeVersion)
 	// Set Engine version number (Same as Lame version)
 	pbeVersion->byMajorVersion=LAME_MAJOR_VERSION;
 	pbeVersion->byMinorVersion=LAME_MINOR_VERSION;
+	pbeVersion->byAlphaLevel=LAME_ALPHA_VERSION;
+	pbeVersion->byBetaLevel=LAME_BETA_VERSION;
+
+#ifdef MMX_choose_table
+	pbeVersion->byMMXEnabled=1;
+#else
+	pbeVersion->byMMXEnabled=0;
+#endif
+
+	memset(pbeVersion->btReserved,0, sizeof(pbeVersion->btReserved));
 
 	// Get compilation date
 	strcpy(lpszDate,__DATE__);
@@ -518,7 +581,7 @@ __declspec(dllexport) VOID		beVersion(PBE_VERSION pbeVersion)
 
 	memset(pbeVersion->zHomepage,0x00,BE_MAX_HOMEPAGE);
 
-	strcpy(pbeVersion->zHomepage,"http://www.sulaco.org/mp3/");
+	strcpy(pbeVersion->zHomepage,"http://www.mp3dev.org/");
 }
 
 __declspec(dllexport) BE_ERR	beEncodeChunk(HBE_STREAM hbeStream, DWORD nSamples, 
@@ -530,12 +593,20 @@ __declspec(dllexport) BE_ERR	beEncodeChunk(HBE_STREAM hbeStream, DWORD nSamples,
 	dwSamples=nSamples/gf.num_channels;
 
 	// old versions of lame_enc.dll required exactly 1152 samples
-	// and worked even if nSamples accidently set to 2304
+	// and worked even if nSamples accidently set to 2304 
 	// simulate this behavoir:
 	if (gf.num_channels==1 && nSamples == 2304)
 	  dwSamples/=2;
 
-	*pdwOutput=lame_encode_buffer_interleaved(&gf,pSamples,dwSamples,pOutput,0);
+
+	if (gf.num_channels==1 )
+	{
+		*pdwOutput=lame_encode_buffer(&gf,pSamples,pSamples,dwSamples,pOutput,0);
+	}
+	else
+	{
+		*pdwOutput=lame_encode_buffer_interleaved(&gf,pSamples,dwSamples,pOutput,0);
+	}
 
 
 	if (*pdwOutput<0) {
@@ -553,24 +624,33 @@ __declspec(dllexport) BE_ERR beWriteVBRHeader(LPCSTR lpszFileName)
 	BE_ERR beResult	=BE_ERR_SUCCESSFUL;
 
 	// Do we have to write the VBR tag?
-	if ( (gf.bWriteVbrTag) && (gf.VBR!=vbr_off) )
+	if ( ( gf.bWriteVbrTag ) && ( gf.VBR != vbr_off ) )
 	{
 		// Calculate relative quality of VBR stream 
 		// 0=best, 100=worst
-		int nQuality=gf.VBR_q*100/9;
+		int nQuality = gf.VBR_q * 100 / 9;
 
 		// Try to open the file
-		fpStream=fopen(lpszFileName,"rb+");
+		fpStream=fopen( lpszFileName, "rb+" );
 
 		// Check file open result
-		if (fpStream==NULL)
-		  return BE_ERR_INVALID_FORMAT_PARAMETERS;
+		if ( NULL == fpStream )
+		{
+			return BE_ERR_INVALID_FORMAT_PARAMETERS;
+		}
 
 		// Write Xing header again
-		beResult=PutVbrTag(&gf,fpStream,nQuality);
+		lame_mp3_tags_fid( &gf, fpStream );
 
 		// Close the file stream
-		fclose(fpStream);
+		fclose( fpStream );
+
+	}
+
+	if ( gf.bWriteVbrTag )
+	{
+		// clean up of allocated memory
+		lame_close( &gf );
 	}
 
 	// return result
@@ -588,24 +668,20 @@ BOOL APIENTRY DllMain(HANDLE hModule,
 	{
 		case DLL_PROCESS_ATTACH:
 			// Enable debug/logging?
-			gs_bLogFile=GetPrivateProfileInt("Debug","WriteLogFile",gs_bLogFile,"lame_enc.ini");
-//			DebugPrintf("Attach Process \n");
+			gs_bLogFile = GetPrivateProfileInt("Debug","WriteLogFile",gs_bLogFile,"lame_enc.ini");
 		break;
 		case DLL_THREAD_ATTACH:
-//			DebugPrintf("Attach Thread \n");
 		break;
 		case DLL_THREAD_DETACH:
-//			DebugPrintf("Detach Thread \n");
 		break;
 		case DLL_PROCESS_DETACH:
-//			DebugPrintf("Detach Process \n");
 		break;
     }
     return TRUE;
 }
 
 
-static void dump_config( char *inPath, char *outPath)
+static void dump_config( )
 {
 	DebugPrintf("\n\nLame_enc configuration options:\n");
 	DebugPrintf("==========================================================\n");
@@ -643,9 +719,10 @@ static void dump_config( char *inPath, char *outPath)
 
 	switch (gf.VBR)
 	{
-		case vbr_off: DebugPrintf("vbr_off\n");	break;
-		case vbr_mt : DebugPrintf("vbr_mt \n");	break;
-		case vbr_rh : DebugPrintf("vbr_rh \n");	break;
+		case vbr_off:	DebugPrintf("vbr_off\n");	break;
+		case vbr_mt :	DebugPrintf("vbr_mt \n");	break;
+		case vbr_rh :	DebugPrintf("vbr_rh \n");	break;
+		case vbr_mtrh:	DebugPrintf("vbr_mtrh \n");	break;
 		case vbr_abr: 
 			DebugPrintf(" vbr_abr (average bitrate %d kbps)\n",gf.VBR_mean_bitrate_kbps);
 		break;
@@ -655,9 +732,6 @@ static void dump_config( char *inPath, char *outPath)
 	}
 
 	DebugPrintf("Write VBR Header       =%s\n",(gf.bWriteVbrTag)?"Yes":"No");
-//	DebugPrintf("input file: '%s'   output file: '%s'\n", inPath, outPath);
-//	DebugPrintf("Voice mode %s\n",(voice_mode)?"enabled":"disabled");
-//	DebugPrintf("Encoding as %.1f kHz %d kbps MPEG-%d LayerIII file\n",gf.out_samplerate/1000.0,gf.brate,gf.mode,3 - gf.version);
 }
 
 
