@@ -48,7 +48,7 @@ typedef		unsigned long			BE_ERR;
 
 /* other constants */
 
-#define		BE_MAX_HOMEPAGE			256
+#define		BE_MAX_HOMEPAGE			128
 
 /* format specific variables */
 
@@ -57,6 +57,8 @@ typedef		unsigned long			BE_ERR;
 #define		BE_MP3_MODE_DUALCHANNEL	2
 #define		BE_MP3_MODE_MONO		3
 
+
+
 #define		MPEG1	1
 #define		MPEG2	0
 
@@ -79,15 +81,27 @@ typedef enum
 
 */
 
+
+typedef enum
+{
+	VBR_METHOD_NONE			= -1,
+	VBR_METHOD_DEFAULT		=  0,
+	VBR_METHOD_OLD			=  1,
+	VBR_METHOD_NEW			=  2,
+	VBR_METHOD_MTRH			=  3,
+	VBR_METHOD_ABR			=  4
+} VBRMETHOD;
+
 typedef enum 
 {
 	LQP_NOPRESET=-1,
 
-	// STANDARD QUALITY PRESETS
+	// QUALITY PRESETS
 	LQP_NORMAL_QUALITY=0,
 	LQP_LOW_QUALITY,
 	LQP_HIGH_QUALITY,
 	LQP_VOICE_QUALITY,
+	LQP_R3MIX_QUALITY,
 
 	// NEW PRESET VALUES
 	LQP_PHONE	=1000,
@@ -150,9 +164,10 @@ typedef struct	{
 			BOOL			bEnableVBR;			// USE VBR ENCODING (TRUE/FALSE)
 			INT				nVBRQuality;		// VBR QUALITY 0..9
 			DWORD			dwVbrAbr_bps;		// Use ABR in stead of nVBRQuality
+			VBRMETHOD		nVbrMethod;
 			BOOL			bNoRes;				// Disable Bit resorvoir
 
-			BYTE			btReserved[255-2*sizeof(DWORD)];	// FUTURE USE, SET TO 0
+			BYTE			btReserved[255-3*sizeof(DWORD)];	// FUTURE USE, SET TO 0
 
 			} LHV1;					// LAME header version 1
 
@@ -192,6 +207,13 @@ typedef struct	{
 
 	CHAR	zHomepage[BE_MAX_HOMEPAGE + 1];	
 
+	BYTE	byAlphaLevel;
+	BYTE	byBetaLevel;
+	BYTE	byMMXEnabled;
+
+	BYTE	btReserved[125];
+
+
 } BE_VERSION, *PBE_VERSION;			
 
 #ifndef _BLADEDLL
