@@ -1,9 +1,8 @@
-#ifdef PARENT_IS_SLASH
-#include "/gtkanal.h"
-#else
-#include "../gtkanal.h"
-#endif
+#include "lame-analysis.h"
+
+#ifndef NOANALYSIS
 extern plotting_data *mpg123_pinfo;
+#endif
 
 struct buf {
         unsigned char *pnt;
@@ -20,8 +19,10 @@ struct framebuf {
 	struct frame *prev;
 };
 
-struct mpstr {
+typedef struct mpstr_tag {
 	struct buf *head,*tail;
+        int vbr_header;               /* 1 if valid Xing vbr header detected */
+        int num_frames;               /* set if vbr header present */
         int header_parsed;
         int side_parsed;  
         int data_parsed;  
@@ -41,8 +42,9 @@ struct mpstr {
 	int bsnum;
 	real synth_buffs[2][2][0x110];
         int  synth_bo;
+        int  look_for_xing;
 	
-};
+} MPSTR, *PMPSTR;
 
 
 #if ( defined(_MSC_VER) || defined(__BORLANDC__) )
@@ -56,8 +58,4 @@ struct mpstr {
 #define MP3_NEED_MORE 1
 
 
-BOOL InitMP3(struct mpstr *mp);
-int decodeMP3(struct mpstr *mp,char *inmemory,int inmemsize,
-     char *outmemory,int outmemsize,int *done);
-void ExitMP3(struct mpstr *mp);
 
